<#
	.SYNOPSIS
		Dumps Aggregate Growth Rates, provide aggregate numbers
	.DESCRIPTION
		Dumps Aggregate Growth Rates, provide aggregate numbers.  Plan to create dashboard for aggregates and predict storage growth
	.EXAMPLE
		.\dfm_vmware_aggr_growth_v2.ps1
	.DATE 
		5-17-2013
	.Version 
	    v2
	.Notes
		.Author 
			Josh Goldfarb 
	.Change Log
	     v1.0 - Initial
		 v2.0 - Updated for global aggregate usage/capacity
	
#>

Function Convert-UnixTime()
{
      #[CmdletBinding()]

      Param(

       [Parameter(Position=0,Mandatory=$True,ValueFromPipeline=$True)]
       [int]$utime
	   )
	   
	   Process  {
       [TimeZone]::CurrentTimeZone.ToLocalTime(([datetime]'1/1/1970').AddSeconds($utime))
               }


}


Function Convert-togb()
{
Param (
 [Parameter(Position=0,Mandatory=$True,ValueFromPipeline=$True)]
 #[int]$data
$data
 )
 
 Process {
 [math]::round($data/1gb)
 }

}

cls
$global=@()
$fdata = @()
#Gather Aggregates for Vmware
 $aggr = dfm aggr list  | ? {$_ -notlike "*aggr0*"} | ?  {$_ -notlike "*traditional*"} |  Select -skip 2 # | % {

 $headers = "Date","Used","Capacity","Trend"


$aggr | % {
	$array= $_ -replace '\s+', " "
		$array = $array.split(" ")
		$filer = $array[1]
		$filer = $filer.split(":")
		$dfmaggr = $array[1]
		$nfiler = $filer[0]
		
			# $dfmaggr
	Write-host "Doing data for Aggr: " $dfmaggr 
	$graph7 = dfm graph -F csv aggregate-usage-vs-total-1w $dfmaggr | ? {$_ -notlike "*-*"} | select -skip 1
	$graph30 = dfm graph -F csv aggregate-usage-vs-total-1m $dfmaggr | ? {$_ -notlike "*-*"} | select -skip 1
	$graph90 = dfm graph -F csv aggregate-usage-vs-total-3m $dfmaggr | ? {$_ -notlike "*-*"} | select -skip 1
	
	
	$data7 =  convertfrom-csv $graph7 -delimiter "," -header $headers
	$data30 = convertfrom-csv $graph30 -delimiter "," -header $headers
	$data90 =  convertfrom-csv $graph90 -delimiter "," -header $headers
### Determine Growth rates to 90% aggr Full

If ((($data30[-1].used | convert-togb) - ($data30[0].used | convert-togb)) -gt 0 )  {
 $90  =  [math]::round((((($data7[-1].capacity | convert-togb) * .90) - ($data7[-1].used | convert-togb)) / (($data30[-1].used | convert-togb) - ($data30[0].used | convert-togb)) ) * 30)
} else {
$90 = ""
}


 
	$customobject = new-object psobject
		add-member -inputobject $customobject -membertype noteproperty -name Filer -value $filer[0]
		add-member -inputobject $customobject -membertype noteproperty -name Aggr -value $filer[1]
		add-member -inputobject $customobject -membertype noteproperty -name "Capacity (GB)" -value ($data7[-1].capacity | convert-togb)
		add-member -inputobject $customobject -membertype noteproperty -name "Used (GB)" -value ($data7[-1].used | convert-togb)
		add-member -inputobject $customobject -membertype noteproperty -name "Free (GB)" -value (($data7[-1].capacity - $data7[-1].used) | convert-togb)
		add-member -inputobject $customobject -membertype noteproperty -name "7 Day (GB)" -value (($data7[-1].used | convert-togb) - ($data7[0].used | convert-togb))
		add-member -inputobject $customobject -membertype noteproperty -name "30 Day (GB)" -value (($data30[-1].used | convert-togb) - ($data30[0].used | convert-togb))
	   	add-member -inputobject $customobject -membertype noteproperty -name "90 Day (GB)" -value (($data90[-1].used | convert-togb) - ($data90[0].used | convert-togb))
	   	add-member -inputobject $customobject -membertype noteproperty -name "Days to 90% Full" -value $90

	   $global += $customobject
	
	clear-variable -name 90
	
}


$Header =@"
<style> 
BODY {background-color:#2E2E2E;}
TABLE {border-width: 1px;border-style: solid;border-color: black;border-collapse: collapse;} 
TH {border-width: 1px;padding: 3px;border-style: solid;border-color: black;background-color: #6495ED; text-align: center;} 
TD {border-width: 1px;padding: 3px;border-style: solid;border-color: black; background-color:Linen; width:100%; height:25px; white-space:nowrap;} 
</style> 
<title> 
Netapp Aggregate Growth
</title>
"@

$a = "<style>"
$a = $a + "BODY{background-color:#2E2E2E;}"
$a = $a + "TABLE{border-width: 1px;border-style: solid;border-color: black;border-collapse: collapse;}"
$a = $a + "TH{border-width: 1px;padding: 1px;border-style: solid;border-color: black;background-color:#6495ED}"
$a = $a + "TD{border-width: 1px;padding: 1px;border-style: solid;border-color: black;background-color:Linen; width:25%%; height:25px; white-space:nowrap;}"
$a = $a + "</style>"
$a = $a + "<title>Netapp Aggregate Growth</title>"



$global | convertto-html -Head $a | Out-File \\netappinfo\httproot$\Global_Aggr_growth.html
$global | ? {$_."Days to 90% Full" -lt 90 }  | ? {$_."Days to 90% Full" -ne ""} | convertto-html -Head $a | Out-File \\netappinfo\httproot$\Trouble_Aggr_growth_.html

$global  | ? {$_."Days to 90% Full" -ne ""} |  Export-csv "\\netappinfo\httproot$\Global_Aggr_growth.csv" -notypeinformation


$global | ft -autosize



 
 